@@ -1,8 +1,9 @@
 /*
- * This file is part of nzbget. See <http://nzbget.net>.
- *
- * Copyright (C) 2012-2016 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * This file is part of nzbget. See <https://nzbget.com>.
  *
+ * Copyright (C) 2012-2019 Andrey Prygunkov <hugbug@users.sourceforge.net>
+ * Copyright (C) 2024 Denis <denis@nzbget.com>
+ * 
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,7 +15,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License
- * along with this program.  If not, see <http://www.gnu.org/licenses/>.
+ * along with this program.  If not, see <https://www.gnu.org/licenses/>.
  */
 
 /*
@@ -57,7 +58,6 @@ var Util = (new function($)
 
 	this.formatTimeLeft = function(sec)
 	{
-		var hms = '';
 		var days = Math.floor(sec / 86400);
 		var hours = Math.floor((sec % 86400) / 3600);
 		var minutes = Math.floor((sec / 60) % 60);
@@ -101,60 +101,81 @@ var Util = (new function($)
 
 		if (sizeMB >= 1024 * 1024 * 100)
 		{
-			return this.round0(sizeMB / 1024.0 / 1024.0) + '&nbsp;TB';
+			return Math.floor(sizeMB / 1024.0 / 1024.0) + ' TB';
 		}
 		else if (sizeMB >= 1024 * 1024 * 10)
 		{
-			return this.round1(sizeMB / 1024.0 / 1024.0) + '&nbsp;TB';
+			return this.round1(sizeMB / 1024.0 / 1024.0) + ' TB';
 		}
 		else if (sizeMB >= 1024 * 1000)
 		{
-			return this.round2(sizeMB / 1024.0 / 1024.0) + '&nbsp;TB';
+			return this.round2(sizeMB / 1024.0 / 1024.0) + ' TB';
 		}
 		else if (sizeMB >= 1024 * 100)
 		{
-			return this.round0(sizeMB / 1024.0) + '&nbsp;GB';
+			return Math.floor(sizeMB / 1024.0) + ' GB';
 		}
 		else if (sizeMB >= 1024 * 10)
 		{
-			return this.round1(sizeMB / 1024.0) + '&nbsp;GB';
+			return this.round1(sizeMB / 1024.0) + ' GB';
 		}
 		else if (sizeMB >= 1000)
 		{
-			return this.round2(sizeMB / 1024.0) + '&nbsp;GB';
+			return this.round2(sizeMB / 1024.0) + ' GB';
 		}
 		else if (sizeMB >= 100)
 		{
-			return this.round0(sizeMB) + '&nbsp;MB';
+			return Math.floor(sizeMB) + ' MB';
 		}
 		else if (sizeMB >= 10)
 		{
-			return this.round1(sizeMB) + '&nbsp;MB';
+			return this.round1(sizeMB) + ' MB';
 		}
 		else
 		{
-			return this.round2(sizeMB) + '&nbsp;MB';
+			return this.round2(sizeMB) + ' MB';
 		}
 	}
 
-	this.formatSpeed = function(bytesPerSec)
+	this.formatSpeed = function (bytesPerSec) 
 	{
-		if (bytesPerSec >= 100 * 1024 * 1024)
+		if (bytesPerSec <= 0)
 		{
-			return Util.round0(bytesPerSec / 1024.0 / 1024.0) + '&nbsp;MB/s';
+			return '';
 		}
-		else if (bytesPerSec >= 10 * 1024 * 1024)
+
+		if (bytesPerSec >= 100 * 1024 * 1024 * 1024) 
 		{
-			return Util.round1(bytesPerSec / 1024.0 / 1024.0) + '&nbsp;MB/s';
+			return Util.round0(bytesPerSec / 1024 / 1024 / 1024) + ' GB/s';
 		}
-		else if (bytesPerSec >= 1024 * 1000)
+		else if (bytesPerSec >= 10 * 1024 * 1024 * 1024) 
 		{
-			return Util.round2(bytesPerSec / 1024.0 / 1024.0) + '&nbsp;MB/s';
+			return Util.round1(bytesPerSec / 1024 / 1024 / 1024) + ' GB/s';
 		}
-		else
+		else if (bytesPerSec >= 1024 * 1024 * 1024) 
 		{
-			return Util.round0(bytesPerSec / 1024.0) + '&nbsp;KB/s';
+			return Util.round2(bytesPerSec / 1024 / 1024 / 1024) + ' GB/s';
 		}
+		if (bytesPerSec >= 100 * 1024 * 1024) 
+		{
+			return Util.round0(bytesPerSec / 1024.0 / 1024.0) + ' MB/s';
+		}
+		else if (bytesPerSec >= 10 * 1024 * 1024) 
+		{
+			return Util.round1(bytesPerSec / 1024.0 / 1024.0) + ' MB/s';
+		}
+		else if (bytesPerSec >= 1024 * 1000) 
+		{
+			return Util.round2(bytesPerSec / 1024.0 / 1024.0) + ' MB/s';
+		}
+
+		return Util.round0(bytesPerSec / 1024.0) + ' KB/s';
+	}
+
+	this.formatSpeedWithCustomUnit = function (bytesPerSec, unit) 
+	{
+		var res = this.formatSpeed(bytesPerSec);
+		return res.replace('B', unit);
 	}
 
 	this.formatAge = function(time)
@@ -342,6 +363,16 @@ var Util = (new function($)
 	    return text.substring(text.length - substr.length, text.length) === substr;
 	}
 
+	this.makeId = function(text)
+	{
+		return text.replace(/ |\/|\\|\.|\$|\:|\*/g, '_');
+	}
+
+	this.joinInt64 = function(hi, lo)
+	{
+		return (hi << 32) + lo;
+	}
+
 }(jQuery));
 
 
@@ -379,7 +410,6 @@ var TabDialog = (new function($)
 		var dialog = this;
 		var body = $('.modal-body', dialog);
 		var footer = $('.modal-footer', dialog);
-		var header = $('.modal-header', dialog);
 		dialog.css({margin: '', left: '', top: '', bottom: '', right: '', width: '', height: ''});
 		body.css({position: '', height: '', left: '', right: '', top: '', bottom: '', 'max-height': ''});
 		footer.css({position: '', left: '', right: '', bottom: ''});
@@ -400,7 +430,6 @@ var TabDialog = (new function($)
 		var header = $('.modal-header', dialog);
 
 		var oldBodyHeight = body.height();
-		var oldWinHeight = dialog.height();
 		var windowWidth = $(window).width();
 		var windowHeight = $(window).height();
 		var oldTabWidth = fromTab.width();
@@ -530,8 +559,8 @@ var RPC = (new function($)
 	'use strict';
 
 	// Properties
-	this.rpcUrl;
-	this.defaultFailureCallback;
+	this.rpcUrl = '';
+	this.defaultFailureCallback = undefined;
 	this.connectErrorMessage = 'Cannot establish connection';
 	this.safeMethods = [];
 	this.etags = {};
